reproduce:
=================================================

About Reproduce
===============

`reproduce` is a library to help you create reproducible computational
pipelines. Its current vision is in the context of science based software.

Example Use
===========

Install `reproduce` with

`pip install reproduce`

Examples coming in later releases.
